use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.17

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Dist/Zilla/Plugin/Git/Contributors.pm',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/01-basic.t',
    't/02-include-authors.t',
    't/03-no-contributors.t',
    't/04-podweaver-warning.t',
    't/05-no-repository.t',
    't/06-include-releaser.t',
    't/07-author-is-releaser.t',
    't/08-order-by.t',
    't/09-unicode.t',
    't/10-no-git-user-configured.t',
    't/11-paths.t',
    't/12-mailmap-files.t',
    't/13-no-commits.t',
    't/14-extract-author.t',
    't/lib/GitSetup.pm',
    't/zzz-check-breaks.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
